from ytnb_embed.custom_exception import InvalidURLException
from ytnb_embed.logger import logger
import re
from IPython.display import HTML, display

def embed_yt(url: str, width: int = 780, height: int = 440):
    try:
        regex = r"(?:v=|\/)([0-9A-Za-z_-]{11}).*"
        match = re.search(regex, url)

        if not match:
            raise InvalidURLException(f"Invalid YouTube URL: {url}")

        video_id = match.group(1)

        embed_url = f"https://www.youtube-nocookie.com/embed/{video_id}"

        iframe = f"""
        <iframe width="{width}" height="{height}"
        src="{embed_url}"
        title="YouTube video player"
        frameborder="0"
        allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
        referrerpolicy="strict-origin-when-cross-origin"
        allowfullscreen>
        </iframe>
        """

        display(HTML(iframe))
        logger.info("YouTube video rendered successfully.")

        return "success"

    except Exception as e:
        raise e



import setuptools
from pathlib import Path

BASE_DIR = Path(__file__).parent
long_description = (BASE_DIR / "README.md").read_text(encoding="utf-8")

__version__ = "1.0.1"

REPO_NAME = "ytnb-embed"
PACKAGE_NAME = "ytnb_embed"
AUTHOR_USER_NAME = "aatansen"
AUTHOR_EMAIL = "aatansen@gmail.com"

setuptools.setup(
    name=REPO_NAME,
    version=__version__,
    author=AUTHOR_USER_NAME,
    author_email=AUTHOR_EMAIL,
    description="Embed youtube video inside notebook",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}",
    project_urls={
        "Bug Tracker": f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}/issues",
    },
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src")
)